@@ -281,7 +281,7 @@ plot_grid_labels_y <- function(gt, scale) {
 
 
 plot_grid <- function(gt, scale, add.labels) {
-	if (gt$grid.labels.inside.frame && any(gt$grid.ticks)) warning("Grid ticks are not supported when labels.inside.frame = TRUE", call. = FALSE)
+	if (gt$grid.labels.inside.frame && any(gt$grid.ticks) && gt$show.warnings) warning("Grid ticks are not supported when labels.inside.frame = TRUE", call. = FALSE)
 	
 	
 	## might be confusing: gridx are grid lines for the x-axis, so they are vertical
