@@ -23,11 +23,13 @@
 #' @export
 tmap_save <- function(tm=NULL, filename=NA, width=NA, height=NA, units = NA,
 					  dpi=NA, outer.margins=NA, asp=NULL, scale=NA, insets_tm=NULL, insets_vp=NULL, add.titles = TRUE, in.iframe = FALSE, selfcontained = !in.iframe, verbose = NULL, ...) {
-	if (!missing(verbose)) warning("The argument verbose is deprecated. Please use the option show.messages of tmap_options instead.")
-	
 	.tmapOptions <- get("tmapOptions", envir = .TMAP_CACHE)
+	show.warnings <-.tmapOptions$show.warnings
+	if (!missing(verbose) && show.warnings) warning("The argument verbose is deprecated. Please use the option show.messages of tmap_options instead.")
+	
 	verbose <- .tmapOptions$show.messages
 	
+	
 	lastcall <- x <- get("last_map", envir = .TMAP_CACHE)
 	if (missing(tm)) {
 		tm <- suppressWarnings(tmap_last())
@@ -121,10 +123,10 @@ tmap_save <- function(tm=NULL, filename=NA, width=NA, height=NA, units = NA,
 	# 	if (is.na(units)) units <- "in"
 	if (is.na(width) || is.na(height)) {
 		if (!is.na(width)) {
-			if (is.na(units)) units <- ifelse(width>50, "px", "in")
+			if (is.na(units)) units = choose_unit(width)
 			temp_size <- convert_to_pixels(width, units)
-		} else if (!is.na(width)) {
-			if (is.na(units)) units <- ifelse(height>50, "px", "in")
+		} else if (!is.na(height)) {
+			if (is.na(units)) units = choose_unit(height)
 			temp_size <- convert_to_pixels(height, units)
 		} else {
 			units <- "px"
@@ -150,7 +152,7 @@ tmap_save <- function(tm=NULL, filename=NA, width=NA, height=NA, units = NA,
 			width <- height * sasp
 		}
 	} else {
-		if (is.na(units)) units <- ifelse(width > 50 || height > 50, "px", "in")
+		if (is.na(units)) units = choose_unit(max(width, height))
 	}
 	units_target <- ifelse(units=="px" && ext %in% c("png", "jpg", "jpeg", "bmp", "tiff"), "px", "in")
 	
@@ -251,3 +253,9 @@ tmap_save <- function(tm=NULL, filename=NA, width=NA, height=NA, units = NA,
 	options(tmap.mode=tmap.mode)
 	invisible()
 }
+
+choose_unit = function(x) {
+	units = ifelse(x > 50, "px", "in")
+	if (x > 15 && x < 100) message("The argument 'units' has been set to \"", units, "\" since the specified width or height is ", ifelse(units == "px", "greater than ", "less than or equal to "), 50, ". Specify units = \"", ifelse(units == "px", "in", "px"),"\" to change this.")
+	units
+}
